@@ -1,13 +1,13 @@
-weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.factor = factor(rep(1, length(treat))),
-                         estimand, focal = NULL, stabilize = FALSE, ps = NULL, moments = NULL, int = NULL,
-                         subclass = NULL, is.MSM.method = FALSE, missing = "ind", include.obj = FALSE, ...){
+weightit.fit <- function(covs, treat, method, treat.type, s.weights = rep(1, length(treat)), by.factor = factor(rep(1, length(treat))),
+                         estimand = "ATE", focal = NULL, stabilize = FALSE, ps = NULL, moments = NULL, int = FALSE,
+                         subclass = NULL, is.MSM.method = FALSE, missing = if (anyNA(covs)) "ind" else "", include.obj = FALSE, ...){
 
   #main function of weightit that dispatches to weightit2method and returns object containing weights and ps
-  out <- setNames(vector("list", 3), c("weights", "ps", "fit.obj"))
+  out <- make_list(c("weights", "ps", "fit.obj"))
 
   treat.type <- match_arg(treat.type, c("binary", "multinomial", "continuous"))
-  if (include.obj) fit.obj <- setNames(vector("list", nlevels(by.factor)), levels(by.factor))
-  info <- setNames(vector("list", nlevels(by.factor)), levels(by.factor))
+  if (include.obj) fit.obj <- make_list(levels(by.factor))
+  info <- make_list(levels(by.factor))
 
   obj <- NULL
   for (i in levels(by.factor)) {
@@ -35,6 +35,8 @@ weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.f
                              subclass = subclass,
                              ps = ps,
                              missing = missing,
+                             moments = moments,
+                             int = int,
                              ...)
       }
 
@@ -125,23 +127,23 @@ weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.f
     else if (method == "twang") {
       if (treat.type %in% c("binary", "multinomial")) {
         obj <- weightit2twang(covs = covs,
-                            treat = treat,
-                            s.weights = s.weights,
-                            estimand = estimand,
-                            focal = focal,
-                            subset = by.factor == i,
-                            stabilize = stabilize,
-                            subclass = subclass,
-                            missing = missing,
-                            ...)
+                              treat = treat,
+                              s.weights = s.weights,
+                              estimand = estimand,
+                              focal = focal,
+                              subset = by.factor == i,
+                              stabilize = stabilize,
+                              subclass = subclass,
+                              missing = missing,
+                              ...)
       }
       else {
         obj <- weightit2twang.cont(covs = covs,
-                                 treat = treat,
-                                 s.weights = s.weights,
-                                 subset = by.factor == i,
-                                 missing = missing,
-                                 ...)
+                                   treat = treat,
+                                   s.weights = s.weights,
+                                   subset = by.factor == i,
+                                   missing = missing,
+                                   ...)
       }
 
     }
@@ -212,15 +214,14 @@ weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.f
                              ...)
       }
       else {
-        # stop("Entropy balancing is not compatible with continuous treatments.", call. = FALSE)
         obj <- weightit2ebal.cont(covs = covs,
-                                    treat = treat,
-                                    subset = by.factor == i,
-                                    s.weights = s.weights,
-                                    moments = moments,
-                                    int = int,
-                                    missing = missing,
-                                    ...)
+                                  treat = treat,
+                                  subset = by.factor == i,
+                                  s.weights = s.weights,
+                                  moments = moments,
+                                  int = int,
+                                  missing = missing,
+                                  ...)
       }
     }
     else if (method == "super") {
@@ -266,6 +267,32 @@ weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.f
         stop("Empirical balancing calibration weights are not compatible with continuous treatments.", call. = FALSE)
       }
     }
+    else if (method == "energy") {
+      if (treat.type %in% c("binary", "multinomial")) {
+        obj <- weightit2energy(covs = covs,
+                               treat = treat,
+                               s.weights = s.weights,
+                               subset = by.factor == i,
+                               estimand = estimand,
+                               focal = focal,
+                               stabilize = stabilize,
+                               moments = moments,
+                               int = int,
+                               missing = missing,
+                               ...)
+      }
+      else {
+        stop("Energy balancing weights are not compatible with continuous treatments.", call. = FALSE)
+        # obj <- weightit2energy.cont(covs = covs,
+        #                             treat = treat,
+        #                             subset = by.factor == i,
+        #                             s.weights = s.weights,
+        #                             moments = moments,
+        #                             int = int,
+        #                             missing = missing,
+        #                             ...)
+      }
+    }
     # else if (method == "kbal") {
     #   if (treat.type %in% c("binary", "multinomial")) {
     #     obj <- weightit2kbal(covs = covs,
@@ -287,7 +314,7 @@ weightit.fit <- function(covs, treat, method, treat.type, s.weights = NULL, by.f
       warning("Some weights were estimated as NA, which means a value was impossible to compute (e.g., Inf). Check for extreme values of the treatment or covariates and try removing them. NA weights will be set to 0.", call. = FALSE)
       obj$w[!is.finite(obj$w)] <- 0
     }
-    else if (any(!is.finite(obj$w))) probably.a.bug()
+    # else if (any(!is.finite(obj$w))) probably.a.bug()
 
     out$weights[by.factor == i] <- obj$w
     if (is_not_null(obj$ps)) out$ps[by.factor == i] <- obj$ps
